viewmydb
--------

Viewmydb is a program for working with MySQL or PostgreSQL databases. Executed from a command-line terminal or shell, viewmydb provides a graphical user interface implemented using Urwid, a framework library based on ncurses. General functions like viewing tables in a database and viewing data in tables is supported, as well as more specific functionality such as creating tables, populating tables with data, and running direct SQL queries against a database from within the program. The application was developed by David Adams and Adam Pedigo as part of their curriculum at Oregon State University while pursuing degrees in Computer Science.

Documentation can be found in the GitHub repository at:
https://github.com/OSU-CS419/viewmydb
